==> fwbuilder_1.0.0.orig.tar.gz: fwbuilder-1.0.0.orig/src/gui/ASDruidP30Dialog.cc <==
// generated 2001/4/7 23:19:37 PDT by vadim@voyager.
// using glademm V0.5_11f_cvs
//
// newer (non customized) versions of this file go to ASDruidP30Dialog.cc_new

// This file is for your program, I won't touch it again!

#include "config.h"
#include "ASDruidP30Dialog.hh"
#include "helpers.hh"
#include "fwbuilder/FWObjectDatabase.hh"

using namespace libfwbuilder;

ASDruidP30Dialog::ASDruidP30Dialog()
{
    FWObject    *smtp, *http, *ssh, *telnet, *ftp, *frag, *icmp;

    p30_txt_1->set_line_wrap(true);
    p30_txt_2->set_line_wrap(true);

    frag=_findObjectByName(FWObjectDatabase::db->std.ServicesId,"ip_fragments");
    smtp=_findObjectByName(FWObjectDatabase::db->std.ServicesId ,"smtp" );
    http=_findObjectByName(FWObjectDatabase::db->std.ServicesId ,"http" );
    ssh=_findObjectByName(FWObjectDatabase::db->std.ServicesId , "ssh" );
    ftp=_findObjectByName(FWObjectDatabase::db->std.ServicesId , "ftp" );
    telnet=_findObjectByName(FWObjectDatabase::db->std.ServicesId ,"telnet" );

    icmp=_findObjectByName(FWObjectDatabase::db->std.ServicesId ,"all_icmp_unreachables" );
 
    if (frag==NULL)    short_fragments->set_sensitive(false);
    if (smtp==NULL)    allow_smtp->set_sensitive(false);
    if (http==NULL)    allow_http->set_sensitive(false);
    if (ssh==NULL)     allow_ssh->set_sensitive(false);
    if (telnet==NULL)  allow_telnet->set_sensitive(false);

    if (icmp==NULL)    allow_icmp->set_sensitive(false);

    setButtonLblAlignment(short_fragments        , 0.0, 0.5);
    setButtonLblAlignment(allow_smtp             , 0.0, 0.5);
    setButtonLblAlignment(allow_http             , 0.0, 0.5);
    setButtonLblAlignment(allow_ssh              , 0.0, 0.5);
    setButtonLblAlignment(allow_ftp              , 0.0, 0.5);
    setButtonLblAlignment(allow_telnet           , 0.0, 0.5);
    setButtonLblAlignment(allow_icmp             , 0.0, 0.5);
    setButtonLblAlignment(allow_all_on_loopback  , 0.0, 0.5);
    setButtonLblAlignment(allow_all_outgoing     , 0.0, 0.5);
    setButtonLblAlignment(catch_all              , 0.0, 0.5);
}

==> fwbuilder_1.1.2.orig.tar.gz: fwbuilder-1.1.2/src/gui/ASDruidP30Dialog.cc <==
// generated 2001/4/7 23:19:37 PDT by vadim@voyager.
// using glademm V0.5_11f_cvs
//
// newer (non customized) versions of this file go to ASDruidP30Dialog.cc_new

// This file is for your program, I won't touch it again!

#include "config.h"
#include "ASDruidP30Dialog.hh"
#include "helpers.hh"
#include "FWObjectDatabaseGUI.hh"

using namespace libfwbuilder;

ASDruidP30Dialog::ASDruidP30Dialog()
{
    FWObject    *smtp, *http, *ssh, *telnet, *ftp, *frag, *icmp;

    p30_txt_1->set_line_wrap(true);
    p30_txt_2->set_line_wrap(true);

    frag=_findObjectByName(FWObjectDatabaseGUI::getServicesId(),"ip_fragments");
    smtp=_findObjectByName(FWObjectDatabaseGUI::getServicesId() ,"smtp" );
    http=_findObjectByName(FWObjectDatabaseGUI::getServicesId() ,"http" );
    ssh=_findObjectByName(FWObjectDatabaseGUI::getServicesId() , "ssh" );
    ftp=_findObjectByName(FWObjectDatabaseGUI::getServicesId() , "ftp" );
    telnet=_findObjectByName(FWObjectDatabaseGUI::getServicesId() ,"telnet" );

    icmp=_findObjectByName(FWObjectDatabaseGUI::getServicesId() ,"all_icmp_unreachables" );
 
    if (frag==NULL)    short_fragments->set_sensitive(false);
    if (smtp==NULL)    allow_smtp->set_sensitive(false);
    if (http==NULL)    allow_http->set_sensitive(false);
    if (ssh==NULL)     allow_ssh->set_sensitive(false);
    if (telnet==NULL)  allow_telnet->set_sensitive(false);

    if (icmp==NULL)    allow_icmp->set_sensitive(false);

    setButtonLblAlignment(short_fragments        , 0.0, 0.5);
    setButtonLblAlignment(allow_smtp             , 0.0, 0.5);
    setButtonLblAlignment(allow_http             , 0.0, 0.5);
    setButtonLblAlignment(allow_ssh              , 0.0, 0.5);
    setButtonLblAlignment(allow_ftp              , 0.0, 0.5);
    setButtonLblAlignment(allow_telnet           , 0.0, 0.5);
    setButtonLblAlignment(allow_icmp             , 0.0, 0.5);
    setButtonLblAlignment(allow_all_on_loopback  , 0.0, 0.5);
    setButtonLblAlignment(allow_all_outgoing     , 0.0, 0.5);
    setButtonLblAlignment(catch_all              , 0.0, 0.5);
}
